@@ -9,7 +9,7 @@ import subprocess
 import logging
 
 """Backup your Digitalocean Droplets"""
-__version__ = '1.0.4'
+__version__ = '1.0.5'
 __author__ = 'Rob Johnson ( https://corndogcomputers.com )'
 __author_email__ = 'info@corndogcomputers.com'
 __license__ = 'The MIT License (MIT)'
@@ -32,21 +32,20 @@ class Backup(object):
     """
 
     def __init__(self, *args, **kwargs):
-        self.success = None
-        self.delay = 5
-        self.ssh_user = ''
-        self.ssh_key = ''
-        self.remote_dirs = []
-        self.rsync_excludes = []
-        self.freshlog = False
-        self.use_ip = False
-        self.debug = False
-        self.user = getpass.getuser()
-        self.home = os.path.expanduser('~')
-        self.backup_dir = '%s/Droplets' % self.home
-        self.snapshot_hour = 25
-        self.keep_snapshots = 0
-        self.debug = False
+        self.success = None  # completion bool
+        self.delay = 5  # delay between api calls
+        self.ssh_user = ''  # ssh user name
+        self.ssh_key = ''  # ssh key
+        self.remote_dirs = []  # droplet directories to rsync
+        self.rsync_excludes = []  # excludes for rsync
+        self.freshlog = False  # start a new log if true
+        self.use_ip = False  # use ip instead of droplet name for ssh
+        self.user = getpass.getuser()  # local system username
+        self.home = os.path.expanduser('~')  # local system home path
+        self.backup_dir = '%s/Droplets' % self.home  # backup dir
+        self.snapshot_hour = 25  # hour of day to take snapshot
+        self.keep_snapshots = 0  # number of snapshots to keep
+        self.debug = False  # debug flag
 
         """Currently no support for Windows without CYGWIN"""
         if os.name != 'posix':
@@ -55,7 +54,7 @@ class Backup(object):
         """Set attributes from args."""
         self.__dict__.update(kwargs)
 
-        """Setup logger."""
+        """Setup logger. (not for markdown logfile)"""
         logging.captureWarnings(True)
         if self.debug == True:
             logging.basicConfig(level=logging.DEBUG)
@@ -240,24 +239,20 @@ class Backup(object):
             """Create a snapshot with a name like @example.com-2015-29-0300."""
             snapshot_name = '@%s-%s' % (self.droplet.name, timestamp)
 
-            off = self.droplet.status == 'off'
-            if off == False:
-                off = self.droplet.power_off(return_dict=False).wait(
-                    update_every_seconds=self.delay)
+            """Take the snapshot."""
+            complete = self.droplet.take_snapshot(
+                snapshot_name,
+                return_dict=False,
+                power_off=True
+            ).wait(update_every_seconds=(self.delay * 2))
 
-            if off == True:
-                """Take the snapshot."""
-                complete = self.droplet.take_snapshot(
-                    snapshot_name,
-                    return_dict=False
-                ).wait(update_every_seconds=(self.delay * 2))
+            """Log the snapshot name and complete result."""
+            self.__log('DROPLET_TAKING_SNAPSHOT: _%s_ %s' % (
+                snapshot_name, complete))
 
-                """Log the snapshot name and complete result."""
-                self.__log('DROPLET_TAKING_SNAPSHOT: _%s_ %s' % (
-                    snapshot_name, complete))
+            if self.keep_snapshots != 0:
+                complete = self.__delete_snapshots()
 
-                if self.keep_snapshots != 0:
-                    complete = self.__delete_snapshots()
         else:
             complete = True
 
@@ -290,6 +285,7 @@ class Backup(object):
                     if self.__remote_dir_check(remote_dir) == True:
                         complete = False
                         params = '-e "ssh -oStrictHostKeyChecking=no -i %s"' % self.ssh_key
+
                         """This is the actual rsync command being sent."""
                         process = '%s %s %s %s@%s:%s/ %s%s' % (
                             rsync,
